import { Draft } from 'immer';

type Selector<T, RT> = (state: T) => RT;
type SetStateVal<T> = Partial<T> | ((val: Draft<T>) => void);
type ListenerFn<T> = (state: T) => void;

/**
 * Creates a store with initial value.
 */
declare function create<T>(initialState: T): {
    useAppState: <ST extends T, RT>(selector: Selector<ST, RT>) => RT;
    setAppState: (val: SetStateVal<T>, replace?: boolean) => Promise<void>;
    api: {
        /** Returns the current state */
        get: () => T;
        /** Merge or replace values in the state */
        set: (val: SetStateVal<T>, replace?: boolean) => Promise<void>;
        /** Resets the current state to the initial state */
        reset: (newState?: T) => void;
        /** Subscribes to the state, called on every state change */
        subscribe: (lf: ListenerFn<T>) => () => boolean;
        /** It removes all listeners */
        destroy: () => void;
    };
};

export { type ListenerFn, type Selector, type SetStateVal, create };
